<?php 

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\Controller\CrudWithParameterBag;

class RelVendaDiaHoraController extends CrudWithParameterBag {
    protected $dataSourceName = 'vnd02500_relVendasDiaHora';
    protected $parameterBagColumns = array('NRORG', 'CDOPERADOR', 'CDFILIAL', 'CDLOJA', 'TCDLOJA', 'DATAINI', 'DATAFIN', 'HRINI', 'HRFIN', 'MINUTOS', 'IDIMPHR');
   
    public function __construct($dataSourceManager, $parameterBag, $utilService) {
        parent::__construct($dataSourceManager, $parameterBag);
        $this->utilService = $utilService;
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $result = [];
        $dataSourceName = $this->dataSourceName = 'vnd02500_relVendasDiaHora';
        
        $conditions = $this->utilService->getParamsAsArray($request);
        $conditions = $this->buildParams($conditions);
        
        if(isset($conditions['DATAINI']) && !empty($conditions['DATAINI']) && 
           isset($conditions['DATAFIN']) && !empty($conditions['DATAFIN'])) {
            foreach($conditions as $key => $value) {
                $dataSourceFilter[] = $condition = array(
                    "columnName" => $key,
                    "operator"   => "=",
                    "value"      => $value
                );
            }
            
            // para o CTRL+F funcionar
            for($i = 0; $i < count($conditions); $i++) {
                if(strpos($dataSourceFilter[$i]["columnName"], '|') != false) {
                    $dataSourceFilter[$i]["operator"] = "MAPPED_LIKE_ALL";
                }
            }
            
            $newRequest = new DTO\Request\Filter (
                new FilterCriteria(
                    $dataSourceName,
                    $dataSourceFilter,
                    $request->getFilterCriteria()->getPage(),
                    $request->getFilterCriteria()->getPageSize()
                ),
                $request->getMethod(),
                $request->getRoutePath(),
                $request->getUserId()
            );
            
            parent::find($newRequest, $response);
        }
        
        return $result;
    }
    
    public function buildParams($conditions) {
        if(!array_key_exists('CDFILIAL', $conditions)) {
            $conditions['CDFILIAL'] = '';
        } else {
            $conditions['CDFILIAL'] = implode('_', $conditions['CDFILIAL']);
            $conditions['CDOPERADOR'] = '';
        }
        
        if(!array_key_exists('CDLOJA', $conditions)) {
            $conditions['CDLOJA'] = '';
            $conditions['TCDLOJA'] = 'T';
        } else {
            $conditions['CDLOJA'] = implode('_', $conditions['CDLOJA']);
            $conditions['TCDLOJA'] = '';
        }
        
        if(array_key_exists('DTPERIODO', $conditions)) {
            $conditions['DATAINI'] = $conditions['DTPERIODO'][0];
            $conditions['DATAFIN'] = $conditions['DTPERIODO'][1];

            unset($conditions['DTPERIODO']);
        }
        
        if(array_key_exists('HRINI', $conditions)) {
            $conditions['HRINI'] = str_replace(['%', ':'], '', $conditions['HRINI']);
        }
        
        if(array_key_exists('HRFIN', $conditions)) {
            $conditions['HRFIN'] = str_replace(['%', ':'], '', $conditions['HRFIN']);
        }
        
        if(array_key_exists('MINUTOS', $conditions)) {
            $conditions['MINUTOS'] = str_replace('%', '', $conditions['MINUTOS']);
        }
        
        if(array_key_exists('IDIMPHR', $conditions)) {
            $conditions['IDIMPHR'] = str_replace('%', '', $conditions['IDIMPHR']);
        }
        
        return $conditions;
    }
}
